@@ -1,3 +1,4 @@
+import os
 import click
 import getpass
 import pyhectiqlab
@@ -18,26 +19,31 @@ def cli():
 @cli.command()
 def add_profile():
 	auth = AuthProvider()
-	username = input("Username: ")
-
+	username = click.prompt('Username ', )
 	if auth.profile_exists(username):
-		click.echo(f'A profile already exists for {username}')
+		click.echo(f'A profile already exists for {username} at {auth.tokens_path}. Try using the pyhectiqlab or delete the profile before executing add-profile.')
 		return
 
 	password = getpass.getpass(prompt='Password: ', stream=None) 
+	try:
+		api_name = socket.gethostname()
+	except:
+		api_name = None
+
+	name = click.prompt('Alias for the key: ', default=api_name)
 	click.echo("Connecting...")
-	success, api_key_uuid = auth.fetch_secret_api_token(username, password)
+	success, api_key_uuid = auth.fetch_secret_api_token(username, password, name)
 
 	if success:
 		click.echo(f'Added profile [{username}] in {auth.tokens_path}')
-		try:
-			api_name = socket.gethostname()
-			ops.update_secret_api_token_name(api_key_uuid, name=api_name, token=auth.secret_api_key)
-			click.echo(f'Set the API-key name to {api_name}.')
-		except:
-			return
+		if (auth.profiles and len(auth.profiles)>1):
+			click.echo(f"You have multiple profiles in {auth.tokens_path}. Use env var HECTIQLAB_PROFILE to switch between profiles.")
+		click.echo('You can now start using hectiqlab 🎉!')
+		click.echo('📚 Documentation at https://docs.hectiq.ai')
+		click.echo('🚀 Web palteform at https://lab.hectiq.ai')
+
 	else:
-		click.echo('Unsuccessful login.')
+		click.echo('😞 Unsuccessful login.')
 
 @cli.command()
 def version():
@@ -99,8 +105,8 @@ def download_app(project, name, save_path, overwrite, raw):
 @click.option('-p', '--project', prompt="Project", help='Path of the project (e.g. `hectiqai/project`)', required=True)
 @click.option('-n', '--name', prompt='App name', help='Name of the app', required=True)
 @click.option('-d', '--description', prompt='App description', help='A one-line description of what the app does', required=False)
-@click.option('--files_path', prompt='Path to the folder containing the app', help='Path to the files',required=True)
-@click.option('--privacy', help='Privacy settings (public or private) ["private"]', type=click.Choice(['public', 'private']), required=True)
+@click.option('--files_path', type=click.Path(exists=True), prompt='Path to the folder containing the app', help='Path to the files',required=True, autocompletion=os.listdir)
+@click.option('--privacy', prompt='Privacy settings (public or private)', type=click.Choice(['public', 'private']), required=True)
 @click.option('--app_type', prompt='The app type',  help='The app type', type=click.Choice(['streamlit', 'gradio', 'plotly']), required=True)
 def create_app(project, name, description, files_path, privacy, app_type):
 	manager = load_event_manager()
@@ -108,19 +114,27 @@ def create_app(project, name, description, files_path, privacy, app_type):
 	if results.get("status_code")!=200:
 		click.echo(results.get("detail", "Something wrong occured."))
 		return
-	click.echo(results.get("payload")["msg"])
+	payload = results.get("payload")
+	if payload.get("owned_by")=="organization":
+		click.echo(f"Showing the instances for {payload.get('owner')}:")
 	instance_types = results.get("results")
-	choices = click.Choice([r["name"] for r in instance_types], case_sensitive=True)
+	choices = click.Choice([r["name"] for r in instance_types if r["selectable"]==True], case_sensitive=True)
 	instances_description = "\n\n"
 	for r in instance_types:
-		instances_description += f"[{r['name']}] {r['points']} points\n  {r['description']}\n  {r['tip']}\n\n"
+		available = ""
+		if r["selectable"]==False:
+			available = "Requies a team membership\n"
+		instances_description += f"{available}[{r['name']}] {r['price']}\n  {r['description']}\n  {r['tip']}\n\n"
 
 	instance_type = click.prompt(f"Select your instance type: {instances_description}", type=choices, show_choices=True)
+	click.echo("Please wait while we create your app...")
 
-	ops_create_app(name=name, 
+	url = ops_create_app(name=name, 
 				project=project,
 				app_type=app_type, 
 				instance=instance_type, 
 				is_private=privacy=="private", 
 				dir_path=files_path, 
 				description=description)
+	click.echo(f"🚀 Your app is not available at {url}")
+	click.launch(url)
\ No newline at end of file
