@@ -20,7 +20,7 @@ def dataset_info_at_path(dirpath: str):
         return None
 
 def upload_dataset(source_path: str, dataset_name: str, project_path: str, run_id: str = None, version: str = None,
-    short_description: str = None, push_dir:bool = False):
+    short_description: str = None, push_dir:bool = False, resume_upload: bool = False):
 
     slug_dataset_name = slugify(dataset_name)
     assert slug_dataset_name==dataset_name, f"The name is not slugified. Please use {slug_dataset_name} instead."
@@ -47,7 +47,7 @@ def upload_dataset(source_path: str, dataset_name: str, project_path: str, run_i
         filenames = [os.path.basename(source_path)]
         full_paths = {os.path.basename(source_path): os.path.abspath(source_path)}
         num_bytes = [os.path.getsize(source_path)]
-    args = (run_id, project_path, filenames, full_paths, num_bytes, dataset_name, short_description, version)
+    args = (run_id, project_path, filenames, full_paths, num_bytes, dataset_name, short_description, version, resume_upload)
     return manager.add_event("add_dataset", args, async_method=False)
 
 def download_dataset(dataset_name: str,
