@@ -47,7 +47,7 @@ class MetricsManager():
     def add(self, key, value, step):
         if value is None:
             return
-        self.cache[key].append((float(step), float(value), dt.datetime.timestamp(dt.datetime.utcnow())))
+        self.cache[key].append((float(step), float(value), dt.datetime.now(tz=dt.timezone.utc).timestamp()))
         if len(self.cache[key])>self.max_cache_length:
             if key in self.cache_last_push:
                 last_push_time = self.cache_last_push[key]
