@@ -1,4 +1,5 @@
 import requests
+import click
 import json
 import pyhectiqlab.settings as settings
 import logging
@@ -20,7 +21,6 @@ def lab_request(path, request_type, form_data=None, query_args=None, body_args=N
         for key, val in query_args.items():
             if val is not None:
                 url += f"{key}={val}&"
-
     headers = {}
     if token:
         headers = {"X-API-Key": f"{token}"}
@@ -37,6 +37,7 @@ def lab_request(path, request_type, form_data=None, query_args=None, body_args=N
         call = requests.put
     elif request_type=="POST":
         call = requests.post
+
     try:
         res = call(url, data=body, headers=headers, files=files)
         logger.debug(url)
@@ -58,10 +59,10 @@ def lab_request(path, request_type, form_data=None, query_args=None, body_args=N
         return {"status_code": 400}
 
 
-def fetch_secret_api_token(username, password):
+def fetch_secret_api_token(name, username, password):
     res = lab_request(path="/app/auth/generate_secret_api_token", 
                 request_type="POST", 
-                form_data=dict(username=username, password=password))
+                body_args=dict(name=name, username=username, password=password, scopes="python-client; "))
     return res
 
 def update_secret_api_token_name(api_key_uuid, name, token):
@@ -391,6 +392,7 @@ def upload_app_files(name,
 
         for policy, filename in zip(res['policies'], batch_filenames):
             logger.info(f'Uploading {filename}')
+            click.echo(f'{filename}')
             upload_file(full_paths[filename], policy)
 
 
