@@ -219,7 +219,7 @@ class Run():
     @write_method
     @action_method
     def add_dataset(self, source_path: str, name: str, version: str = None, description: str = None,
-                push_dir: bool = False):
+                push_dir: bool = False, resume_upload: bool = False):
         """Add a dataset.
 
         source_path: Path to the directory/file of the dataset
@@ -229,6 +229,7 @@ class Run():
             dataset with this name (e.g. 1.3.3 -> 1.4.0)
         description: Short description.
         push_dir: Must be set to True if the source_path is a directory
+        resume_upload: Use resume_upload to resume a failed upload.
         """
         dataset = ops_upload_dataset(source_path=source_path, 
             dataset_name=name,
@@ -236,7 +237,8 @@ class Run():
              project_path=self._project_path,
              version=version,
              short_description=description,
-             push_dir=push_dir)
+             push_dir=push_dir,
+             resume_upload=resume_upload)
         if dataset is not None:
             self.add_dataset_usage(dataset.get('name'), version=dataset.get('version'))
 
@@ -314,13 +316,18 @@ class Run():
 
     @write_method
     @action_method
-    def add_directory_as_zip_artifact(self, dirpath: str, step: int = None):
+    def add_directory_as_zip_artifact(self, dirpath: str, name: str = None, step: int = None, wait_response: bool = False):
         """Compress a full directory and add the compressed file as an artifact.
+
+        name [str]: Use this to overwrite the name of the artifact. If None, the basename of the filepath is used.
+                    Use this especially if you are using step artifacts and you want to group multiple files
+                    with different names.
+        step [int]: The optional step stamp of the artifacts.
         """
         p = tempfile.mkdtemp()
         filename = os.path.basename(dirpath)
         shutil.make_archive(f"{p}/{filename}", 'zip', root_dir=dirpath)
-        self.add_artifact(f"{p}/{filename}.zip", step=step)
+        self.add_artifact(f"{p}/{filename}.zip", name=name, step=step, wait_response=wait_response)
 
     @write_method
     @action_method
@@ -482,6 +489,14 @@ class Run():
         args = (self._id, self._project_path, content)
         self.events_manager.add_event("set_paper", args)
 
+    @write_method
+    @action_method
+    def clear_logs(self):
+        """Clear the entire saved logs.
+        """
+        args = (self._id, self._project_path)
+        self.events_manager.add_event("clear_logs", args)
+
     def _stream_exception(self):
         """
         Handle the exception with `sys.excepthook`.
