@@ -4,8 +4,8 @@ import uuid
 import numpy as np
 from pyhectiqlab import Run, Config, AuthProvider
 
-run_name = f'test {uuid.uuid4()}'
-run = Run(name=run_name, project='test', should_create_project=True)
+run_name = f'Test {str(uuid.uuid4())[:5]}'
+run = Run(name=run_name, project='hectiq-ai/test')
 
 class CreateRunTest(unittest.TestCase):
 
@@ -25,6 +25,7 @@ class CreateRunTest(unittest.TestCase):
     def test_add_tag(self):
         self.hectiq_run.add_tag(name='hello', description='This run is a test')
         self.hectiq_run.add_tag(name='world')
+        self.hectiq_run.add_tag(name='orange', color="#e6550d")
 
     def test_add_packages(self):
         self.hectiq_run.add_package_versions(globals())
@@ -40,19 +41,24 @@ class CreateRunTest(unittest.TestCase):
             self.hectiq_run.add_metrics(key, value, step)
 
     def test_add_artifact(self):
-        self.hectiq_run.add_artifact('./test_img1.jpeg')
-        self.hectiq_run.add_artifact('./test_img2.jpeg')
+        self.hectiq_run.add_artifact('./artifacts/test_img1.jpeg')
+        self.hectiq_run.add_artifact('./artifacts/test_img2.jpeg')
 
     def test_add_step_artifact(self):
-        self.hectiq_run.add_artifact('./test_img2.jpeg', step=1)
+        self.hectiq_run.add_artifact('./step_artifacts/step1.jpeg', step=1)
+        self.hectiq_run.add_artifact('./step_artifacts/step2.jpeg', step=2)
+        self.hectiq_run.add_artifact('./step_artifacts/step3.jpeg', step=3)
+        self.hectiq_run.add_artifact('./step_artifacts/step4.jpeg', step=4)
+        self.hectiq_run.add_artifact('./step_artifacts/step8.jpeg', step=8)
+        self.hectiq_run.add_artifact('./step_artifacts/step9.jpeg', step=9)
 
     def test_add_config(self):
-        sub_config = Config(c='hello world', d=1.5, e=True)
+        sub_config = Config(c='hello world', d=1.5, e=True, small_list=["orange", "apple", "honey"])
         config = Config(a=1, sub_config=sub_config)
         self.hectiq_run.add_config(config=config)
 
     def test_log(self):
-        logger = self.hectiq_run.start_recording_logs()
+        logger = self.hectiq_run.start_recording_logs("test")
         logger.info('info')
         logger.warning('warning')
         logger.error('error')
